#!/usr/bin/perl -w
#
# gpreparegallery - resize each image given on the command line and generate txt file.
# Copyright (C) 2009  Stephane Galland <galland@arakhne.org>
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; see the file COPYING.  If not, write to
# the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
# Boston, MA 02111-1307, USA.
# 

require 5.004;

use strict ;

use File::Basename ;
use File::Spec ;

#------------------------------------------------------
#
# Initialization code
#
#------------------------------------------------------
my $PERLSCRIPTDIR ;
my $PERLSCRIPTNAME ;
my $LAUNCHINGNAME ;
{
	BEGIN{
	  # Where is this script?
	  $PERLSCRIPTDIR = "$0";
	  $LAUNCHINGNAME = basename("$0");
	  my $scriptdir = dirname( $PERLSCRIPTDIR );
	  while ( -e $PERLSCRIPTDIR && -l $PERLSCRIPTDIR ) {
	    $PERLSCRIPTDIR = readlink($PERLSCRIPTDIR);
	    if ( substr( $PERLSCRIPTDIR, 0, 1 ) eq '.' ) {
	      $PERLSCRIPTDIR = File::Spec->catfile( $scriptdir, "$PERLSCRIPTDIR" ) ;
	    }
	    $scriptdir = dirname( $PERLSCRIPTDIR );
	  }
	  $PERLSCRIPTNAME = basename( $PERLSCRIPTDIR ) ;
	  $PERLSCRIPTDIR = dirname( $PERLSCRIPTDIR ) ;
	  $PERLSCRIPTDIR = File::Spec->rel2abs( "$PERLSCRIPTDIR" );
	  # Push the path where the script is to retreive the arakhne.org packages
	  push(@INC,"$PERLSCRIPTDIR");
	  push(@INC,File::Spec->catfile("$PERLSCRIPTDIR","pm"));


	}
}

use Locale::gettext;
use POSIX; # Needed for setlocale()

use GPrepareGalleryWindow;
use PrepareGallery q/preparegallery/;

use constant TRUE => (1==1);
use constant FALSE => (1==0);

my @GENERATION_DATA = ();

sub searchIcon() {
	my @paths = (	File::Spec->catfile('','usr','local','share','icons'),
			File::Spec->catfile('','usr','share','icons'),
			"$PERLSCRIPTDIR" );
	foreach my $path (@paths) {
		my $f = File::Spec->catfile("$path", 'preparegallery.png');
		if (-r "$f") {
			return "$f";
		}
	}
	return undef;
}

#------------------------------------------------------
#
# MAIN PROGRAM: Treat main program actions
#
#------------------------------------------------------

# Set the default locale
setlocale(LC_MESSAGES, "");

my $img = searchIcon();

my $gui = GPrepareGalleryWindow->new (
		$img, 
		"$PERLSCRIPTDIR",
		sub { @GENERATION_DATA = @_; return TRUE; } );

$gui->showDialog();

if (@GENERATION_DATA) {
	my $dirname = $GENERATION_DATA[0];
	my @files = ();
	local *DIR;
	opendir(*DIR, "$dirname") or die("$dirname: $!\n");
	while (my $n = readdir(*DIR)) {
		if ($n ne File::Spec->curdir() && $n ne File::Spec->updir()) {
			if (($n =~ /\.jpg$/i)||
			    ($n =~ /\.jpeg$/i)||
			    ($n =~ /\.png$/i)||
			    ($n =~ /\.bmp$/i)||
			    ($n =~ /\.gif$/i)) {
				push @files, File::Spec->catfile("$dirname","$n");
			}
		}
	}
	closedir(*DIR);

	if (@files) {
		my $CALLBACK_POS = 0;
		my ($outDir,$errors) = preparegallery(sub {
				$CALLBACK_POS ++;
				my $percent = ($CALLBACK_POS * 1.0) / @files;
				$gui->setProgress($percent);
			},
			@GENERATION_DATA,@files);
		my $outBase = basename("$outDir");

		my $dialog;

		if ($errors && @{$errors}) {
			my $msg = join(', ', @{$errors});
			$dialog = Gtk2::MessageDialog->new_with_markup(
				$gui,
				'modal', 'error', 'close',
				$gui->T("Some errors has been encountered on following photos ({} image{}/{}):\n{}", int(@{$errors}), (int(@{$errors})>1?"s":""), int(@files), $msg));
		}
		else {
			$dialog = Gtk2::MessageDialog->new_with_markup(
				$gui,
				'modal', 'info', 'close',
				$gui->T("Generation finished.\nGallery is put in directory \"<a href=\"file:{}\">{}</a>\" (click to open).", $outDir, $outBase));
		}

		$dialog->run();
		$dialog->destroy();
	}
}

$gui->destroy();

exit(0);

__END__
